{#entry.loaded_parts} {^data_idx} {?inline}

{content_ihtml|s}

{:else}

{content_html|s}

{/inline} {:else} {?ordinal_text}

### {ordinal_text} {title}

{:else}

### {title}

{/ordinal_text} {?summary} {summary} {! should be markdown, should check !} {/summary} {?attrs}

{#attrs} {@eq key=type value="default"}
- {title}: {value}
{/eq} {/attrs} {#links}{#value}
- {title}
{/value}{/links}

{/attrs} {?content} {?inline}

{content_ihtml|s}

{:else}

{content_html|s}

{/inline} {/content} {/data_idx}

{/entry.loaded_parts}